
// Includes definitions relevant to the peripherals embedded in the digital signal controller.
#include "F2806x_Device.h"

// Includes the definitions of the constants used in the program
#include "constants.h"


// Function related the the setup of the hardware when using the BoosterBoard_01
int Initialize_the_Clocks(void){
    int Result=CORRECT;

    if(SysCtrlRegs.PLLSTS.bit.MCLKSTS==1){
        Result=ERROR;
    }
    else{

        EALLOW;

// Initializes the clock generation
        SysCtrlRegs.XCLK.bit.XCLKOUTDIV=3;      // Disables the clock output pin
        SysCtrlRegs.CLKCTL.bit.XCLKINOFF=1;     // Disables the input for the external clock
        SysCtrlRegs.CLKCTL.bit.INTOSC2OFF=1;    // Disables the internal oscillator 2

// Initialize the PLL (see pag. 82 of the TMS320x2806x Technical Reference Manual)
        SysCtrlRegs.PLLSTS.bit.DIVSEL=0;        // Sets the CPU clock frequency equal to the oscillator clock frequency/4
        SysCtrlRegs.PLLSTS.bit.MCLKOFF=1;       // Disable failed oscillator detect logic
        SysCtrlRegs.PLLCR.bit.DIV=8;            // Sets the PLL output frequency to 8*oscillator lock frequency

        while(SysCtrlRegs.PLLSTS.bit.PLLLOCKS==0){
                                                // Waits for the PLL to lock
        }

        SysCtrlRegs.PLLSTS.bit.MCLKOFF=0;       // Enables failed oscillator detect logic

        SysCtrlRegs.PLLSTS.bit.DIVSEL=3;        // Sets the CPU clock frequency equal to the oscillator clock frequency
                                     // In this case is 80 MHz. The maximum is 90 MHz

// Sets the peripheral clock frequency
        SysCtrlRegs.LOSPCP.bit.LSPCLK=2;        // Peripheral Low Speed Clock = System Clock/4

        EDIS;
    }

    return Result;
}


int Initialize_the_GPIO(void){
    int Result=CORRECT;
// GPIO 34 and GPIO 39 are connected to the LAUNCHXL LEDs
    EALLOW;

    GpioCtrlRegs.GPBMUX1.bit.GPIO34=0;          // Sets GPIO34 as general purposes digital I/O
    GpioCtrlRegs.GPBMUX1.bit.GPIO39=0;          // Sets GPIO39 as general purposes digital I/O

    GpioCtrlRegs.GPBDIR.bit.GPIO34=1;           // Configures GPIO34 as output
    GpioCtrlRegs.GPBDIR.bit.GPIO39=1;           // Configures GPIO39 as output

    GpioDataRegs.GPBSET.bit.GPIO34=1;           // Sets pin GPIO34
    GpioDataRegs.GPBSET.bit.GPIO39=1;           // Sets pin GPIO39


    EDIS;

    return Result;
}


int Manage_LEDs(int action, int color){
    int Result=CORRECT;

    if(action==TURN_ON){
        if(color==RED){
            GpioDataRegs.GPBCLEAR.bit.GPIO34=1;
        }
        else{
            if(color==BLUE){
                GpioDataRegs.GPBCLEAR.bit.GPIO39=1;
            }
            else{
                Result=ERROR;
            }
        }
    }
    else{
        if(action==TURN_OFF){
            if(color==RED){
                GpioDataRegs.GPBSET.bit.GPIO34=1;
            }
            else{
                if(color==BLUE){
                    GpioDataRegs.GPBSET.bit.GPIO39=1;
                }
                else{
                    Result=ERROR;
                }
            }
        }
        else{
            Result=ERROR;
        }

    }

    return Result;
}

